<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 4.3.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews" class="woocommerce-Reviews">
	<div id="comments">
		<h2 class="woocommerce-Reviews-title">
			<?php
			$count = $product->get_review_count();
			if ( $count && wc_review_ratings_enabled() ) {
				/* translators: 1: reviews count 2: product name */
				$reviews_title = sprintf( esc_html( _n( '%1$s review for %2$s', '%1$s reviews for %2$s', $count, 'juliet' ) ), esc_html( $count ), '<span>' . get_the_title() . '</span>' );
				echo apply_filters( 'woocommerce_reviews_title', $reviews_title, $count, $product ); // WPCS: XSS ok.
			} else {
				esc_html_e( 'Reviews', 'juliet' );
			}
			?>
		</h2>

		<?php if ( have_comments() ) : ?>

			<ol class="commentlist">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ol>

			<?php
			if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links(
					apply_filters(
						'woocommerce_comment_pagination_args',
						array(
							'prev_text' => '&larr;',
							'next_text' => '&rarr;',
							'type'      => 'list',
						)
					)
				);
				echo '</nav>';
			endif;
			?>

		<?php else : ?>
			<p class="woocommerce-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'juliet' ); ?></p>
		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>

		<div id="review_form_wrapper">
			<div id="review_form">
				<?php
                
					$commenter = wp_get_current_commenter();
                    
                    if ( wc_review_ratings_enabled() ) {
                        $comment_field =
                            '<div class="row form-group comment-form-rating">
                                <div class="col-md-2 form-label">' . esc_html__( 'Your rating', 'juliet' ) . ( wc_review_ratings_required() ? '&nbsp;<span class="asterisk">*</span>' : '' ) . '</div>
                                <div class="col-md-8"><select name="rating" id="rating" aria-required="true" required>
                                        <option value="">' . esc_html__( 'Rate&hellip;', 'juliet' ) . '</option>
                                        <option value="5">' . esc_html__( 'Perfect', 'juliet' ) . '</option>
                                        <option value="4">' . esc_html__( 'Good', 'juliet' ) . '</option>
                                        <option value="3">' . esc_html__( 'Average', 'juliet' ) . '</option>
                                        <option value="2">' . esc_html__( 'Not that bad', 'juliet' ) . '</option>
                                        <option value="1">' . esc_html__( 'Very poor', 'juliet' ) . '</option>
                                    </select></div>
                            </div>';
                    } else {
                        $comment_field = '';
                    }

                    $comment_textarea = '
                        <div class="row form-group comment-form-comment">
                            <div class="col-md-2 form-label">' . esc_html__( 'Your review', 'juliet' ) . ' <span class="asterisk">*</span></div>
                            <div class="col-md-8"><textarea id="comment" class="form-control" name="comment" cols="45" rows="8" aria-required="true" required></textarea></div>
                        </div>';

                    $final_comment_field = $comment_field . $comment_textarea;

                    $name_email_required = (bool) get_option( 'require_name_email', 1 );
                    if($name_email_required){ $field_html_required_1 = ' <span class="asterisk">*</span>'; $field_html_required_2 = 'aria-required="true" required ';}
		                                
					$comment_form = array(
						'title_reply'          => esc_html__( 'Add a review', 'juliet' ),
						'title_reply_to'       => esc_html__( 'Leave a Reply to %s', 'juliet' ),
						'title_reply_before'   => '<h2 id="reply-title" class="comment-reply-title">',
						'title_reply_after'    => '</h2>',
                        'comment_field'        => $final_comment_field,
						'comment_notes_after'  => '',
						'fields'               => array(
                            'author' => '<div class="row form-group comment-form-author">
		                                    <div class="col-md-2 form-label">' . esc_html__( 'Name', 'juliet' ) . $field_html_required_1 . '</div>' .
		                                    '<div class="col-md-8"><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" class="form-control" ' . $field_html_required_2 . ' /></div>
		                                </div>',
                            'email'  => '<div class="row form-group comment-form-author">
		                                    <div class="col-md-2 form-label">' . esc_html__( 'Email Address', 'juliet' ) . $field_html_required_1 . '</div>' .
		                                    '<div class="col-md-8"><input id="email" name="email" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" class="form-control" '. $field_html_required_2 .' /></div>
		                                </div>',
						),
						'label_submit'  => esc_html__( 'Submit', 'juliet' ),
						'class_submit' => 'btn btn-dark btn-block',
						'logged_in_as'  => '',
					);

					$account_page_url = wc_get_page_permalink( 'myaccount' );
                    if ( $account_page_url ) {
                        /* translators: %s opening and closing link tags respectively */
                        $comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf( esc_html__( 'You must be %1$slogged in%2$s to post a review.', 'juliet' ), '<a href="' . esc_url( $account_page_url ) . '">', '</a>' ) . '</p>';
                    }

					comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
				?>
			</div>
		</div>

	<?php else : ?>

		<p class="woocommerce-verification-required"><?php _e( 'Only logged in customers who have purchased this product may leave a review.', 'juliet' ); ?></p>

	<?php endif; ?>

	<div class="clear"></div>
</div>
